<?php
/**
 * 漫道短信接口发送实现.
 * User: King
 * Date: 2016/12/26
 * Time: 10:53
 */
namespace Niaoyun\Common\Sms;

class EnInfo extends BaseSms implements ISms
{
    private $errorArr = [
        1    => '没有需要取得的数据',
        -2   => '账号/密码不正确',
        -4   => '余额不足',
        -5   => '数据格式错误',
        -6   => '参数有误',
        -7   => '权限受限',
        -8   => '流量控制错误',
        -9   => '扩展码权限错误',
        -10  => '内容过长',
        -11  => '内部数据库错误',
        -12  => '序列号状态错误',
        -13  => '没有提交增值内容',
        -14  => '服务器写文件失败',
        -15  => '文件内容base64编码错误',
        -16  => '返回报告库参数错误',
        -17  => '没有权限',
        -18  => '上次提交未返回，不能提交',
        -19  => '禁止同时使用多个接口地址',
        -20  => '相同手机号，相同内容重复提交',
        -22  => '禁止同时使用多个接口地址',
        -23  => '缓存无此序列号信息',
        -601 => '序列号为空，参数错误',
        -602 => '序列号格式错误，参数错误',
        -603 => '密码为空，参数错误',
        -604 => '手机号码为空，参数错误',
        -605 => '内容为空，参数错误',
        -606 => 'ext长度大于9，参数错误',
        -607 => '参数错误 扩展码非数字 ',
        -608 => '参数错误 定时时间非日期格式',
        -609 => 'rrid长度大于18,参数错误 ',
        -610 => '参数错误 rrid非数字',
        -611 => '参数错误 内容编码不符合规范',
        -623 => '手机个数与内容个数不匹配',
        -624 => '扩展个数与手机个数数',
        -625 => '定时时间个数与手机个数数不匹配',
        -626 => 'rrid个数与手机个数数不匹配',
    ];

    private $api;               // 接口名
    private $mobile;            // 手机号
    private $content;           // 内容
    private $url;               // 接口地址
    private $params;            // 请求参数
    private $headers = null;    // 请求头

    /**
     * @return string
     */
    public function getApi()
    {
        return $this->api;
    }

    /**
     * @param string $api
     */
    public function setApi($api)
    {
        $this->api = $api;
    }

    /**
     * @return mixed
     */
    public function getMobile()
    {
        return $this->mobile;
    }

    /**
     * @param mixed $mobile
     */
    public function setMobile($mobile)
    {
        $this->mobile = $mobile;
    }

    /**
     * @return mixed
     */
    public function getContent()
    {
        // content要gb2312编码！
        return iconv('utf-8', 'gb2312', $this->content);
    }

    /**
     * @param mixed $content
     */
    public function setContent($content)
    {
        if (isset($this->config['signature']) && !empty($this->config['signature'])) {
            $content = $this->config['signature'] . $content;
        }
        $this->content = $content;
    }

    /**
     * @return mixed
     */
    public function getUrl()
    {
        return $this->url;
    }

    /**
     * @param mixed $url
     */
    public function setUrl($url)
    {
        $this->url = $url;
    }

    /**
     * @return mixed
     */
    public function getParams()
    {
        return $this->params;
    }

    /**
     * @return array
     */
    public function setParams()
    {
        $params = [
            'sn'      => $this->_getSn(),
            'pwd'     => $this->_getPassword(),
            'mobile'  => $this->getMobile(),
            'content' => $this->getContent(),
            'ext'     => '',
            'stime'   => '',
            'rrid'    => $this->getMessageId(),
        ];
        $this->params = $params;
    }

    /**
     * @return mixed
     */
    public function getHeaders()
    {
        return $this->headers;
    }

    /**
     * @param mixed $headers
     */
    public function setHeaders($headers)
    {
        $this->headers = $headers;
    }

    private $config = [];

    public function __construct()
    {
        $this->config = [
            'url'       => 'https://api.smsbao.com/sms?',
            'apiId'     => C('smg.smgApiId'),
            'apiKey'    => C('smg.smgApiKey'),
            'signature' => C('smg.smgSignatureMd'),
        ];
    }

    /**
     * 实现接口发送方法
     * @auth King
     *
     * @param $mobile
     * @param $content
     * @param $id
     * @param $type
     * @param $params
     *
     * @return bool
     */
    public function send($mobile, $content, $id = null, $type =2, $params = [],$handleResult = true)
    {
        $smsapi = $this->config['url'];
        $user = $this->config['apiId']; //短信平台帐号
        $pass = md5($this->config['apiKey']); //短信平台密码
        $content=$this->config['signature'].$content;//要发送的短信内容
        $phone = $mobile;//要发送短信的手机号码
        $sendurl = $smsapi."u=".$user."&p=".$pass."&m=".$phone."&c=".urlencode($content);
        $result =file_get_contents($sendurl) ;
//        var_dump($result);die;

        $statusStr = array(
            "0" => "短信发送成功",
            "-1" => "参数不全",
            "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
            "30" => "密码错误",
            "40" => "账号不存在",
            "41" => "余额不足",
            "42" => "帐户已过期",
            "43" => "IP地址限制",
            "50" => "内容含有敏感词"
        );
        if (is_numeric($result) && $result > 0) {
            $this->error = $result . $statusStr[$result];

            return false;
        }

        return true;

//        $this->setApi('mt');
//        $this->setMobile($mobile);
//        $this->setContent($content);
//        $this->setMessageId($id); // id 由控制类生成
//        $this->setUrl($this->config['url'] . '/' . $this->api);
//        $this->setParams();
//        $this->setHeaders(null);
//
//        $result = $this->sendPost($this->url, $this->params, $this->headers);
//
//        return $this->processSendResult($result);
    }

    /**
     * 处理短信接口返回数据
     * @auth King
     *
     * @param string $result
     *
     * @return bool
     */
    private function processSendResult($result)
    {
        if (is_bool($result) && !$result) {
            $this->error = '接口不通';
            return $result;
        }

        $res = simplexml_load_string($result);
        $code = strval($res); // string
        if (array_key_exists($code, $this->errorArr)) {
            $this->error = $this->errorArr[$code];

            return false;
        }

        if (is_numeric($code) && $code < 0) {
            $this->error = $code . ' 未知错误';

            return false;
        }

        return true;
    }

    private function _getSn()
    {
        return isset($this->config['apiId']) ? $this->config['apiId'] : '';
    }

    private function _getPassword()
    {
        return strtoupper(md5($this->_getSn() . $this->config['apiKey']));
    }
}